@@ -1,7 +1,7 @@
 (function () {
     "use strict";
 
-    /* malevic@0.19.1 - Jan 8, 2022 */
+    /* malevic@0.20.1 - Jan 14, 2024 */
     function m$1(tagOrComponent, props, ...children) {
         props = props || {};
         if (typeof tagOrComponent === "string") {
@@ -15,7 +15,7 @@
         throw new Error("Unsupported spec type");
     }
 
-    /* malevic@0.19.1 - Jan 8, 2022 */
+    /* malevic@0.20.1 - Jan 14, 2024 */
     function createPluginsStore() {
         const plugins = [];
         return {
@@ -74,6 +74,7 @@
 
     const XHTML_NS = "http://www.w3.org/1999/xhtml";
     const SVG_NS = "http://www.w3.org/2000/svg";
+
     const PLUGINS_CREATE_ELEMENT = Symbol();
     const pluginsCreateElement = createPluginsStore();
     function createElement(spec, parent) {
@@ -445,7 +446,10 @@
     }
     function nodeMatchesSpec(node, spec) {
         return (
-            node instanceof Element && spec.type === node.tagName.toLowerCase()
+            node instanceof Element &&
+            ((node.namespaceURI === XHTML_NS &&
+                spec.type === node.tagName.toLocaleLowerCase()) ||
+                (node.namespaceURI !== XHTML_NS && spec.type === node.tagName))
         );
     }
     const refinedElements = new WeakMap();
@@ -1552,9 +1556,7 @@
     function hslToString(hsl) {
         const {h, s, l, a} = hsl;
         if (a != null && a < 1) {
-            return `hsla(${toFixed(h)}, ${toFixed(s * 100)}%, ${toFixed(
-                l * 100
-            )}%, ${toFixed(a, 2)})`;
+            return `hsla(${toFixed(h)}, ${toFixed(s * 100)}%, ${toFixed(l * 100)}%, ${toFixed(a, 2)})`;
         }
         return `hsl(${toFixed(h)}, ${toFixed(s * 100)}%, ${toFixed(l * 100)}%)`;
     }
